=================
Command reference
=================

Archetypal provides many commands for managing packages and environments.
The links on this page provide help for each command.
You can also access help from the command line with the
``--help`` flag:

.. code-block:: bash

   archetypal --help

.. include:: commands/convert.rst

.. include:: commands/reduce.rst

.. include:: commands/transition.rst
